Parser

Struct Parser 

pub struct Parser { /* private fields */ }
A parser for a sequence of .tree tokens into an abstract syntax tree (AST).

This struct represents the state of the parser. It is not tied to any particular input, while ParserI is.

Implementations

Source

impl Parser

pub const fn new() -> Self

Create a new parser.

pub fn parse(&mut self, text: &str, tokens: &[Token]) -> Result<Ast, Error>

Parse the given tokens into an abstract syntax tree (AST).

parse is the entry point for the parser. It takes a sequence of tokens and returns an AST.