pub struct Position {
pub offset: usize,
pub line: usize,
pub column: usize,
}Expand description
A single position.
A position encodes one half of a span, and includes the char offset, line number and column number.
Fields
offset: usizeThe absolute offset of this position, starting at 0 from the
beginning of the tree.
Note that this is a char offset, which lets us use it when
indexing into the original source string.
line: usizeThe line number, starting at 1.
column: usizeThe approximate column number, starting at 1.
Implementations
Sourceimpl Position
impl Position
Sourcepub const fn new(offset: usize, line: usize, column: usize) -> Self
pub const fn new(offset: usize, line: usize, column: usize) -> Self
Create a new position with the given information.
offset is the absolute offset of the position, starting at 0 from
the beginning of the tree.
line is the line number, starting at 1.
column is the approximate column number, starting at 1.