pub struct Span {
pub start: Position,
pub end: Position,
}Expand description
Span represents the position information of a single token.
All span positions are absolute char offsets that can be used on the original tree that was parsed.
Fields
start: PositionThe start char offset.
end: PositionThe end char offset.
Implementations
Sourceimpl Span
impl Span
Sourcepub const fn new(start: Position, end: Position) -> Self
pub const fn new(start: Position, end: Position) -> Self
Create a new span with the given positions.
Sourcepub const fn splat(pos: Position) -> Self
pub const fn splat(pos: Position) -> Self
Create a new span using the given position as the start and end.
Sourcepub const fn with_start(self, pos: Position) -> Self
pub const fn with_start(self, pos: Position) -> Self
Create a new span by replacing the starting position with the one given.