pub struct Token {
pub kind: TokenKind,
pub span: Span,
pub lexeme: String,
}Expand description
Token represents a single unit of meaning in a .tree.
A token has a kind, a span, and a lexeme. The kind is the type of the token, the span is the range in which a token appears in the original text, and the lexeme is the text that the token represents.
Fields
kind: TokenKindThe type of the token.
span: SpanThe range in which a token appears in the original text.
lexeme: StringThe literal characters that make up the token.