pub enum Ast {
Root(Root),
Condition(Condition),
Action(Action),
ActionDescription(Description),
}Expand description
An Abstract Syntax Tree (AST) that describes the semantic structure of a bulloak tree.
Variants
Root(Root)
The root node of the AST.
Condition(Condition)
A condition node of the AST.
This node corresponds to a junction in the tree.
Action(Action)
An action node of the AST.
This node corresponds to a leaf node of the tree.
ActionDescription(Description)
Additional action description.
This node can only appear as a child of an action.
Implementations